==> kxmleditor-0.6.tar.gz: kxmleditor-0.6/kxmleditor/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : t ec 10 12:39:26 CEST 2001
    copyright            : (C) 2001 by Lumir Vanek
    email                : lvanek@eanet.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>

#include "kxmleditor.h"

static const char *description =
	I18N_NOOP("KXML Editor is utility to display and edit XML files");
	
	
static KCmdLineOptions options[] =
{
  { "+[File]", I18N_NOOP("file to open"), 0 },
  { 0, 0, 0 }
  // INSERT YOUR COMMANDLINE OPTIONS HERE
};

int main(int argc, char *argv[])
{

	KAboutData aboutData("kxmleditor",
													I18N_NOOP("KXML Editor"),
													VERSION,
													description,
													KAboutData::License_GPL,
													"(c) 2001, The KXML Editor Developers",
													0,
													"http://kxmleditor.sourceforge.net",
													"lvanek@eanet.cz");
	
	aboutData.addAuthor("Lumir Vanek", I18N_NOOP("Main developer and maintainer"), "lvanek@eanet.cz"); 	
	aboutData.addAuthor("Olaf Hartig", I18N_NOOP("XML tree inplace editing, many bug fixes, useful ideas"), "olaf@punkbands.de"); 		
	
	KCmdLineArgs::init( argc, argv, &aboutData );
	KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.

  KApplication app;
 
  if (app.isRestored())
  	{ RESTORE(KXMLEditorApp);
  	}
  else 
  {
    KXMLEditorApp *kxmleditor = new KXMLEditorApp();
    kxmleditor->show();

    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
		
		if(args->count())
			{ QString strPath;
			
			  if(args->count() > 1)
					{ strPath = args->arg(1);
					}
				
					kxmleditor->openDocumentFile(args->arg(0), strPath);
			}
		else
			{ kxmleditor->openDocumentFile();
			}
		args->clear();
  }

  int iRetVal = app.exec();
  return iRetVal;
}

==> kxmleditor_0.7.1.orig.tar.gz: kxmleditor-0.7.1/kxmleditor/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : t ec 10 12:39:26 CEST 2001
    copyright            : (C) 2001 by The KXMLEditor Team
    email                : lvanek@eanet.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>
#include <dcopclient.h>

#include "kxmleditor.h"
#include "kxmleditorabout.h"


static KCmdLineOptions options[] =
{
  { "+[File]", I18N_NOOP("file to open"), 0 },
  { 0, 0, 0 }
  // INSERT YOUR COMMANDLINE OPTIONS HERE
};

int main(int argc, char *argv[])
{
	KCmdLineArgs::init( argc, argv, new KXMLEditorAboutData() );
	KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.

  KApplication app;

  if (app.isRestored())
  	{ RESTORE(KXMLEditorApp);
  	}
  else
  {
    KXMLEditorApp *kxmleditor = new KXMLEditorApp();
    kxmleditor->show();

    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

		if(args->count())
			{ QString strPath;

			  if(args->count() > 1)
					{ strPath = args->arg(1);
					}

					kxmleditor->openDocumentFile(args->arg(0), strPath);
			}
		else
			{ kxmleditor->openDocumentFile();
			}
		args->clear();
  }

  int iRetVal = app.exec();
  return iRetVal;
}
